@@ -4,10 +4,10 @@ from aiohttp import web
 from aiohttp_middlewares import error_middleware, get_error_response
 from aiohttp_middlewares.annotations import Middleware
 
-from ..annotations import DictStrAny, Handler
-from .constants import REQUEST_CORE_OPERATION_KEY
-from .core_data import find_core_operation
-from .validators import validate_request, validate_response
+from rororo.annotations import DictStrAny, Handler
+from rororo.openapi.constants import REQUEST_CORE_OPERATION_KEY
+from rororo.openapi.core_data import find_core_operation
+from rororo.openapi.validators import validate_request, validate_response
 
 
 def get_actual_handler(handler: Handler) -> Handler:
@@ -88,7 +88,7 @@ def openapi_middleware(
                 validate_response(request, response)
 
             return response
-        except Exception as err:  # noqa: PIE786
+        except Exception as err:
             return await get_error_response(
                 request, err, **error_middleware_kwargs or {}
             )
